# flag to allow local users to mount partitions. This is *really* not a good
# idea, because all users who have access to the device can do whatever they
# want with the data, and it also adds a root setuid binary to your system, so
# use it on your own risk. Refer to
# http://www.tuxera.com/community/ntfs-3g-faq/#useroption for details.
%define allow_unsafe_mount 0

%if %{allow_unsafe_mount}
# user mount only works if ntfs-3g is using internal fuse library
%define build_external_fuse 0
%else
%define build_external_fuse 1
%endif

%define major 88
%define libname %mklibname ntfs-3g %{major}
%define devname %mklibname ntfs-3g -d

Summary:	Read-write ntfs driver
Name:		ntfs-3g
Version:	2017.3.23
Release:	1
License:	GPLv2+
Group:		System/Base
Url:		http://www.tuxera.com/community/ntfs-3g-download/
Source0:	http://tuxera.com/opensource/%{name}_ntfsprogs-%{version}.tgz
Source1:	20-ntfs-config-write-policy.fdi
Patch0:		ntfs-3g_ntfsprogs-2011.10.9-RC-ntfsck-unsupported-return-0.patch
BuildRequires:	attr-devel
BuildRequires:	pkgconfig(gnutls)
BuildRequires:	pkgconfig(libgcrypt)
%if %{build_external_fuse}
BuildRequires:	pkgconfig(fuse)
Requires:	fuse
Requires(pre):	fuse
%else
Requires:	kmod(fuse)
%endif
Requires:	%{libname} = %{EVRD}
Provides:	ntfsprogs-gnomevfs = %{EVRD}
Provides:	ntfsprogs-fuse = %{EVRD}
Provides:	fuse-ntfs-3g = %{EVRD}
Obsoletes:	ntfsprogs < %{EVRD}
%rename ntfsprogs

%description
The ntfs-3g package contains NTFS filesystem driver with read and
write support. It provides safe and fast handling of MS Windows Vista,
XP, 2000 and Server 2003 NTFS file systems. Most POSIX file system
operations are supported.

%files
%doc README AUTHORS CREDITS NEWS
%{_bindir}/ntfsmount
/bin/lowntfs-3g
/bin/ntfs-3g
/bin/ntfs-3g.probe
/bin/ntfsfallocate
/bin/ntfscat
/bin/ntfscluster
/bin/ntfscmp
/bin/ntfsfix
/bin/ntfsinfo
/bin/ntfsls
/bin/ntfsck
/bin/ntfsdecrypt
/bin/ntfsdump_logfile
/bin/ntfsmftalloc
/bin/ntfsmove
/bin/ntfsrecover
/bin/ntfssecaudit
/bin/ntfsusermap
/bin/ntfstruncate
/bin/ntfswipe
/sbin/mkfs.ntfs
/sbin/fsck.ntfs
/sbin/mkntfs
/sbin/ntfsclone
/sbin/ntfscp
/sbin/ntfslabel
/sbin/ntfsresize
/sbin/ntfsundelete
%{_mandir}/man8/*
%if %{allow_unsafe_mount}
%attr(4755,root,root) /sbin/mount.ntfs-3g
%else
%attr(754,root,root) /sbin/mount.ntfs-3g
%endif
/sbin/mount.ntfs
/sbin/mount.lowntfs-3g
/sbin/mount.ntfs-fuse
%{_datadir}/hal/fdi/policy/10osvendor/20-ntfs-config-write-policy.fdi

#----------------------------------------------------------------------------

%package -n %{libname}
Summary:	Shared library for ntfs-3g
Group:		System/Libraries
Requires:	%{name} >= %{EVRD}
Conflicts:	%{name} < 2014.2.15-5

%description -n %{libname}
Shared library for ntfs-3g.

%files -n %{libname}
/%{_lib}/libntfs-3g.so.%{major}*

#----------------------------------------------------------------------------

%package -n %{devname}
Summary:	Header files and static libraries for ntfs-3g
Group:		Development/C
Requires:	%{name} = %{EVRD}
Provides:	%{name}-devel = %{EVRD}
Provides:	lib%{name}-devel = %{EVRD}
Conflicts:	%{name}-devel < 2014.2.15-5
Obsoletes:	%{name}-devel < 2014.2.15-5

%description -n %{devname}
You should install this package if you wish to develop applications that
use ntfs-3g.

%files -n %{devname}
%doc ChangeLog
/%{_lib}/libntfs-3g.so
%{_includedir}/ntfs-3g
%{_libdir}/pkgconfig/*.pc

#----------------------------------------------------------------------------

%prep
%setup -qn %{name}_ntfsprogs-%{version}
%patch0 -p1 -b .unsupported

%build
export CFLAGS="%{optflags} -fPIC"
%configure2_5x \
	--disable-static \
	--exec-prefix=/ \
	--bindir=/bin \
	--libdir=/%{_lib} \
	--sbindir=/sbin \
	--disable-ldconfig \
	--enable-crypto \
	--enable-extras \
	--enable-quarantined \
%if %{build_external_fuse}
	--with-fuse=external
%else
	--with-fuse=internal
%endif
%make

%install
sed -i -e 's|/sbin/ldconfig|true|' src/Makefile
%makeinstall_std

# make the symlink an actual copy to avoid confusion
rm -rf %{buildroot}/sbin/mount.ntfs-3g
cp -a %{buildroot}/bin/ntfs-3g %{buildroot}/sbin/mount.ntfs-3g
ln -sf /sbin/mount.ntfs-3g %{buildroot}/sbin/mount.ntfs
ln -sf /sbin/mount.ntfs-3g %{buildroot}/sbin/mount.ntfs-fuse
mkdir -p %{buildroot}%{_bindir}
ln -sf /sbin/mount.ntfs-3g %{buildroot}%{_bindir}/ntfsmount

# Need this for fsck to find it
ln -s ../bin/ntfsck %{buildroot}/sbin/fsck.ntfs

# .pc file should always be there
mkdir -p %{buildroot}%{_libdir}
mv -f %{buildroot}/%{_lib}/pkgconfig %{buildroot}%{_libdir}/pkgconfig

# remove doc files, as we'll cp them later
rm -fr %{buildroot}/%{_datadir}/doc

mkdir -p %{buildroot}%{_datadir}/hal/fdi/policy/10osvendor/
cp -a %{SOURCE1} %{buildroot}%{_datadir}/hal/fdi/policy/10osvendor/

%changelog

* Wed Mar 29 2017 Alzim <alzim@bk.ru> 2017.3.23-1
- (424111a) Updated to 2017.3.23


